Module executor

Module executor 

SDBQL Query Executor

This module provides the query execution engine for SDBQL.

Re-exports

pub use types::*;
pub use utils::*;

Modules

phonetic
search
Search and vector functions for SDBQL executor.
types
utils

Structs

QueryExecutor
Query executor for SDBQL

Functions

compare_values
contains_window_functions
Check if an expression contains window functions
evaluate_binary_op
evaluate_unary_op
extract_window_functions
Extract all window functions from an expression with their assigned variable names Returns: Vec<(var_name, function_name, arguments, WindowSpec)>
generate_window_key
Generate a unique key for a window function based on its signature
get_field_value
to_bool
values_equal