SDBQL Query Executor
This module provides the query execution engine for SDBQL.
Re-exports
Modules
Structs
- Query
Executor - Query executor for SDBQL
Functions
- compare_
values - contains_
window_ functions - Check if an expression contains window functions
- evaluate_
binary_ op - evaluate_
unary_ op - extract_
window_ functions - Extract all window functions from an expression with their assigned variable names Returns: Vec<(var_name, function_name, arguments, WindowSpec)>
- generate_
window_ key - Generate a unique key for a window function based on its signature
- get_
field_ value - to_bool
- values_
equal